@@ -108,12 +108,8 @@ bool Cache::addItem(Source::Result const& result)
     query.bindValue(":street", result.street);
     query.bindValue(":city", result.city);
 
-    qDebug() << result.number << result.name << result.street << result.city;
-
-
     if(!query.exec())
     {
-        qDebug() << "Unable to add item to cache";
         ret = false;
     }
 
