@@ -130,7 +130,7 @@ void ContactManager::stringToName(QString const& strname, ContactManager::Name&
         QString firstname = QString::fromUtf8(ename->given);
         QString surname = QString::fromUtf8(ename->family);
 
-        if(additional.isEmpty() && check.indexIn(firstname, 1) == -1 && check.indexIn(surname, 1) == -1)
+        if(additional.isEmpty() && check.indexIn(firstname, 1) == -1 && check.indexIn(surname, 1) == -1 && firstname != surname)
         {
             name.firstname = firstname;
             name.surname = surname;
