@@ -106,6 +106,14 @@ void DasTelefonbuch::addNumbers(SearchData* searchData,
                            QString const& data,
                            int index)
 {
+    if(data.isEmpty())
+    {
+        qDebug() << "Server returned no data";
+        setError(CONNECTION_FAILURE, "Server returned no data");
+        emitRequestFinished(searchData, true, index);
+        return;
+    }
+
     if(data.indexOf("<span>1&nbsp;Gesamttreffer</span>") > 0)
     {
         addOnlyNumber(searchData, data, index);
