@@ -81,11 +81,13 @@ private:
     virtual void handleHttpError(int id);
     QUrl createUrl(QString const& query, QString const& location);
     void loadResults(int id, QString const& data);
+    void loadFinnishPersonResults(int id, QString const& data);
     void loadNumber(int id, QString const& data);
     void getNumberForResult(int id, int index, SearchDetails const& details);
     void emitRequestFinished(int key, SearchData* data, bool error);
     void timerEvent(QTimerEvent *t);
     bool isStreet(QString const& str);
+    QString& cleanUpString(QString& str);
 
     Site site_;
     bool loggedIn_;
